# pySDFGen

SDFGen for Python

## Install

```
pip install pysdfgen
```

## Example

```
$ python
>>> from pysdfgen import obj2sdf
>>> obj2sdf('./examples/bunny.obj')
# ./examples/bunny.sdf will be created.
```
